Struct ComplexMexicanHat
pub struct ComplexMexicanHat {
pub omega0: f64,
}Expand description
Complex Mexican Hat (Ricker) Wavelet
A complex version of the Mexican Hat wavelet, excellent for detecting singularities and discontinuities in financial data such as jumps, crashes, or sudden volatility changes.
Mathematical form: ψ(t) = (1 - t²) * exp(-t²/2) * exp(iω₀t)
Fields
omega0: f64Central frequency parameter
Implementations
impl ComplexMexicanHat
impl ComplexMexicanHat
pub fn for_jump_detection() -> Self
pub fn for_jump_detection() -> Self
Create version optimized for jump detection in financial data